pub async fn create_report_schedule(
    configuration: &Configuration,
    body: CreateReportScheduleSpecification
) -> Result<CreateReportScheduleResponse, Error>
Creates a report schedule. If a report schedule with the same report type and marketplace IDs already exists, it will be cancelled and replaced with this one. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.0222 | 10 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.