pub async fn get_report_document(
    configuration: &Configuration,
    report_document_id: &str
) -> Result<GetReportDocumentResponse, Error>
Returns the information required for retrieving a report document’s contents. This includes a presigned URL for the report document as well as the information required to decrypt the document’s contents. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.0167 | 15 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.